
/*

$Id: compile.sql,v 1.3 2003/07/09 14:12:40 oradb Exp $

Compile the db packages and demos we require

*/

@table
@header
@body
@package
@procedure
@function

